@@ -15,7 +15,10 @@ from tornado import escape
 from tornado import websocket
 from tornado.web import RequestHandler, Application
 from tornado.util import ObjectDict
-from tornado.options import enable_pretty_logging
+try:
+    from tornado.log import enable_pretty_logging
+except ImportError:
+    from tornado.options import enable_pretty_logging
 from livereload.task import Task
 
 
@@ -131,7 +134,7 @@ class IndexHandler(RequestHandler):
 
     def read_path(self, abspath):
         filepath = abspath
-        if abspath.endswith('/'):
+        if os.path.isdir(filepath):
             filepath = os.path.join(abspath, 'index.html')
             if not os.path.exists(filepath):
                 self.create_index(abspath)
@@ -142,8 +145,15 @@ class IndexHandler(RequestHandler):
         if os.path.exists(filepath):
             for line in open(filepath):
                 if '</head>' in line:
+                    before, after = line.split("</head>")
+                    # If there is stuff in front of </head>, write it before
+                    # injecting the script
+                    self.write(before)
                     self.inject_livereload()
-                self.write(line)
+                    self.write("</head>")
+                    self.write(after)
+                else:
+                    self.write(line)
             return
         self.send_error(404)
         return
@@ -198,7 +208,10 @@ def start(port=35729, root='.', autoraise=False):
         webbrowser.open(
             'http://127.0.0.1:%s' % port, new=2, autoraise=True
         )
-    ioloop.IOLoop.instance().start()
+    try:
+        ioloop.IOLoop.instance().start()
+    except KeyboardInterrupt:
+        print('Shutting down...')
 
 
 if __name__ == '__main__':
